@@ -249,7 +249,16 @@ bool Applet::destroyed() const
 KConfigLoader *Applet::configScheme() const
 {
     if (!d->configLoader) {
-        const QString xmlPath = d->package.isValid() ? d->package.filePath("mainconfigxml") : QString();
+        QString xmlPath;
+
+        if (d->package.isValid()) {
+            xmlPath = d->package.filePath("mainconfigxml");
+        } else {
+            if (QFile::exists(qrcPath() + QLatin1String("main.xml"))) {
+                xmlPath = qrcPath() + QLatin1String("main.xml");
+            }
+        }
+
         KConfigGroup cfg = config();
         if (xmlPath.isEmpty()) {
             d->configLoader = new KConfigLoader(cfg, nullptr);
@@ -697,15 +706,22 @@ QList<QAction *> Applet::internalActions() const
 Types::FormFactor Applet::formFactor() const
 {
     Containment *c = containment();
-    QObject *pw = qobject_cast<QObject *>(parent());
-    Plasma::Applet *parentApplet = qobject_cast<Plasma::Applet *>(pw);
-    // assumption: this loop is usually is -really- short or doesn't run at all
-    while (!parentApplet && pw && pw->parent()) {
-        pw = pw->parent();
-        parentApplet = qobject_cast<Plasma::Applet *>(pw);
+
+    if (!c) {
+        return Plasma::Types::Planar;
     }
 
-    return c ? c->d->formFactor : Plasma::Types::Planar;
+    // Let's try to return the higher level formfactor in case of
+    // nested containments.
+    // c->containment() is guaranteed to exist except during teardown.
+    // if c is a toplevel containment,
+    // c == c->containment() else if is a nested one, it will be containment's
+    // containment
+    Containment *topC = c->containment();
+    if (topC) {
+        return topC->d->formFactor;
+    }
+    return c->d->formFactor;
 }
 
 Types::ContainmentDisplayHints Applet::containmentDisplayHints() const
@@ -718,7 +734,7 @@ Types::ContainmentDisplayHints Applet::containmentDisplayHints() const
 Containment *Applet::containment() const
 {
     Containment *c = qobject_cast<Containment *>(const_cast<Applet *>(this));
-    if (c && c->isContainment()) {
+    if (c && c->isContainment() && c->containmentType() != Containment::CustomEmbedded) {
         return c;
     } else {
         c = nullptr;
@@ -780,7 +796,22 @@ QKeySequence Applet::globalShortcut() const
 Types::Location Applet::location() const
 {
     Containment *c = containment();
-    return c ? c->d->location : Plasma::Types::Desktop;
+
+    if (!c) {
+        return Plasma::Types::Desktop;
+    }
+
+    // Let's try to return the higher level location in case of
+    // nested containments.
+    // c->containment() is guaranteed to exist except during teardown.
+    // if c is a toplevel containment,
+    // c == c->containment() else if is a nested one, it will be containment's
+    // containment
+    Containment *topC = c->containment();
+    if (topC) {
+        return topC->d->location;
+    }
+    return c->d->location;
 }
 
 bool Applet::hasConfigurationInterface() const
@@ -819,12 +850,19 @@ QUrl Applet::fileUrl(const QByteArray &key, const QString &filename) const
 {
     if (d->package.isValid()) {
         return d->package.fileUrl(key, filename);
+    } else {
+        return QUrl(QLatin1String("qrc") + qrcPath() + filename);
     }
-    return QUrl();
 }
 
 QUrl Applet::mainScript() const
 {
+    const QString path = qrcPath() + QLatin1String("main.qml");
+
+    if (QFile::exists(path)) {
+        return QUrl(QLatin1String("qrc") + path);
+    }
+
     if (d->package.isValid()) {
         return d->package.fileUrl("mainscript");
     }
@@ -835,6 +873,11 @@ QUrl Applet::configModel() const
 {
     if (d->package.isValid()) {
         return d->package.fileUrl("configmodel");
+    } else {
+        const QString path = qrcPath() + QLatin1String("config.qml");
+        if (QFile::exists(path)) {
+            return QUrl(QLatin1String("qrc") + path);
+        }
     }
 
     return QUrl();
@@ -842,6 +885,10 @@ QUrl Applet::configModel() const
 
 bool Applet::sourceValid() const
 {
+    if (QFile::exists(qrcPath())) {
+        return QFile::exists(qrcPath() + QLatin1String("main.qml"));
+    }
+
     return d->package.isValid();
 }
 
@@ -875,14 +922,12 @@ void Applet::timerEvent(QTimerEvent *event)
 
 bool Applet::isContainment() const
 {
-    // HACK: this is a special case for the systray
-    // containment in an applet that is not a containment
-    Applet *pa = qobject_cast<Applet *>(parent());
-    if (pa && !pa->isContainment()) {
-        return true;
-    }
     // normal "acting as a containment" condition
-    return qobject_cast<const Containment *>(this) && qobject_cast<Corona *>(parent());
+    const Containment *cont = qobject_cast<const Containment *>(this);
+    if (!cont) {
+        return false;
+    }
+    return qobject_cast<Corona *>(parent()) || cont->containmentType() == Containment::CustomEmbedded;
 }
 
 QString Applet::translationDomain() const
@@ -895,6 +940,11 @@ QString Applet::translationDomain() const
     }
 }
 
+QString Applet::qrcPath() const
+{
+    return QLatin1String(":/qt/qml/plasma/applet/") + pluginName().replace(QLatin1Char('.'), QLatin1Char('/')) + QLatin1String("/");
+}
+
 } // Plasma namespace
 
 #include "moc_applet.cpp"
