@@ -648,7 +648,7 @@ AppletQuickItem *AppletQuickItem::itemForApplet(Plasma::Applet *applet)
     qmlObject->completeInitialization();
 
     // A normal applet has UI ready as soon as is loaded, a containment, only when also the wallpaper is loaded
-    if (!pc || !pc->isContainment()) {
+    if (!pc || !pc->isContainment() || pc->containmentType() == Plasma::Containment::CustomEmbedded) {
         applet->updateConstraints(Plasma::Applet::UiReadyConstraint);
         applet->flushPendingConstraintsEvents();
     }
@@ -937,6 +937,21 @@ void AppletQuickItem::setExpandedOnDragHover(bool expandedOnDragHover)
     Q_EMIT expandedOnDragHoverChanged(expandedOnDragHover);
 }
 
+QString AppletQuickItem::badgeText() const
+{
+    return d->badgeText;
+}
+
+void AppletQuickItem::setBadgeText(const QString &text)
+{
+    if (text == d->badgeText) {
+        return;
+    }
+
+    d->badgeText = text;
+    Q_EMIT badgeTextChanged(text);
+}
+
 ////////////Internals
 
 PlasmaQuick::SharedQmlEngine *AppletQuickItem::qmlObject()
